searchData={"items":[{"type":"module","title":"LiveTable","doc":"LiveTable is a powerful Phoenix LiveView component library that provides dynamic, interactive tables with built-in support for sorting, filtering, pagination, and data export capabilities.\n  Makes use of [`Oban`](https://hex.pm/packages/oban), [`NimbleCSV`](https://hex.pm/packages/nimble_csv) and [`Typst`](https://typst.app/universe) to handle exports.\n\n**You can find a table with 1 Million rows [here](https://live-table.fly.dev)**","ref":"LiveTable.html"},{"type":"module","title":"Features - LiveTable","doc":"- **Advanced Filtering System**\n    - Text search across multiple fields\n    - Range filters for numbers, dates, and datetimes\n    - Boolean filters with custom conditions\n    - Select filters with static and dynamic options\n    - Multi-column filtering support\n\n  - **Smart Sorting**\n    - Multi-column sorting\n    - Sortable associated fields\n    - Customizable sort directions\n    - Shift-click support for multi-column sorting\n\n  - **Flexible Pagination**\n    - Configurable page sizes\n    - Dynamic page navigation\n    - Efficient database querying\n\n  - **Export Capabilities**\n    - CSV export with background processing\n    - PDF export using Typst\n    - Custom file naming and formatting\n    - Progress tracking for large exports\n\n  - **Real-time Updates**\n    - LiveView integration\n    - Instant filter feedback\n    - Background job status updates","ref":"LiveTable.html#module-features"},{"type":"module","title":"Installation - LiveTable","doc":"Add `live_table` to your list of dependencies in `mix.exs`:\n\n  ```elixir\n  def deps do\n    [\n      {:live_table, \"~> 0.2.0\"}\n    ]\n  ```","ref":"LiveTable.html#module-installation"},{"type":"module","title":"Configuration - LiveTable","doc":"Configure LiveTable in your `config/config.exs`:\n\n  ```elixir\n  config :live_table,\n    repo: YourApp.Repo,\n    pubsub: YourApp.PubSub,\n    components: YourApp.Components  # Optional, defaults to LiveTable.Components\n  ```","ref":"LiveTable.html#module-configuration"},{"type":"module","title":"JavaScript Setup - LiveTable","doc":"Add the following to your `assets/js/app.js`:\n\n  ```js\n  import { TableHooks } from \"../../deps/live_table/priv/static/live-table.js\"\n  let liveSocket = new LiveSocket(\"/live\", Socket, {\n    params: {_csrf_token: csrfToken},\n    hooks: TableHooks\n  })\n  ```","ref":"LiveTable.html#module-javascript-setup"},{"type":"module","title":"CSS Setup - LiveTable","doc":"Add the following to your `assets/tailwind.config.js`:\n\n```javascript\ncontent: [\n  // Other paths\n  \"../deps/live_table/priv/static/*.js\",\n  \"../deps/live_table/**/*.*ex\"\n]\n```\nAnd add the following to your `assets/css/app.css`:\n```css\n@import \"../../deps/live_table/priv/static/live-table.css\";\n```","ref":"LiveTable.html#module-css-setup"},{"type":"module","title":"Oban - LiveTable","doc":"Configure your Oban instance and queues in your `config/config.exs`:\n\n```elixir\n# config/config.exs\nconfig :live_table, Oban,\n  repo: YourApp.Repo,\n  engine: Oban.Engines.Basic,\n  notifier: Oban.Notifiers.Postgres,\n  plugins: [Oban.Plugins.Pruner],\n  queues: [exports: 10]\n  # the queue named `exports` will be used for export jobs\n```\n\n#### Oban Web: Optional\nYou can configure oban web in your router to monitor the background jobs.\n\n  ```elixir\n  # lib/your_app_web/router.ex\n  import Oban.Web.Router\n\n  scope \"/\", YouAppWeb do\n    # your other routes\n    oban_dashboard(\"/oban\")\n  end\n  ```\n\n> **Note**: Remember to add exports to your list of allowed `static_paths` in `lib/app_web.ex`\n\n```elixir\ndef static_paths, do: ~w(assets fonts images favicon.ico exports robots.txt)\n```","ref":"LiveTable.html#module-oban"},{"type":"module","title":"Basic Usage - LiveTable","doc":"In your LiveView add the line `use LiveTable.LiveResource`:\n\n  Define your fields and filters as required.\n  ```elixir\n  #/app_web/live/user_live/index.ex\n  defmodule MyAppWeb.UserLive.Index do\n    use MyAppWeb, :live_view\n    use LiveTable.LiveResource, resource: \"users\", schema: User # Add this line\n\n    # Define fields\n    def fields do\n      [\n        id: %{label: \"ID\", sortable: true},\n        name: %{label: \"Name\", sortable: true, searchable: true},\n        email: %{label: \"Email\", sortable: true, searchable: true},\n\n        # Include fields from associations\n        supplier: %{\n          label: \"Supplier\",\n          sortable: true,\n          searchable: true,\n          assoc: {:supplier, :name}\n        }\n      ]\n    end\n\n    # Define filters\n    def filters do\n      [\n        # Boolean filter\n        active: Boolean.new(:active, \"active\", %{\n          label: \"Active Users\",\n          condition: dynamic([q], q.active == true)\n        }),\n\n        # Range filter\n        age: Range.new(:age, \"age\", %{\n          type: :number,\n          label: \"Age Range\",\n          min: 0,\n          max: 100\n        }),\n\n        # Select filter with dynamic options\n        supplier: Select.new({:suppliers, :name}, \"supplier\", %{\n          label: \"Supplier\",\n          options_source: {YourApp.Suppliers, :search_suppliers, []}\n        })\n      ]\n    end\n  ```\n\n  ```elixir\n    #/app_web/live/user_live/index.html.heex\n    # in your view:\n    <.live_table\n      fields={fields()}\n      filters={filters()}\n      options={@options}\n      streams={@streams}\n    />\n  ```\n> **Note**: Using `shift` + click on a column header will sort by multiple columns.","ref":"LiveTable.html#module-basic-usage"},{"type":"module","title":"Filter Types - LiveTable","doc":"","ref":"LiveTable.html#module-filter-types"},{"type":"module","title":"Boolean Filter - LiveTable","doc":"```elixir\n  Boolean.new(:active, \"active_filter\", %{\n    label: \"Show Active Only\",\n    condition: dynamic([p], p.active == true)\n  })\n  ```","ref":"LiveTable.html#module-boolean-filter"},{"type":"module","title":"Range Filter - LiveTable","doc":"```elixir\n  Range.new(:price, \"price_range\", %{\n    type: :number,\n    label: \"Price Range\",\n    min: 0,\n    max: 1000,\n    step: 10\n  })\n  ```","ref":"LiveTable.html#module-range-filter"},{"type":"module","title":"Select Filter - LiveTable","doc":"```elixir\n  Select.new(:category, \"category_select\", %{\n    label: \"Category\",\n    options: [\n      %{label: \"Electronics\", value: [1, \"Electronics\"]},\n      %{label: \"Books\", value: [2, \"Books\"]}\n    ]\n  })\n  ```","ref":"LiveTable.html#module-select-filter"},{"type":"module","title":"Defining your fields - LiveTable","doc":"","ref":"LiveTable.html#module-defining-your-fields"},{"type":"module","title":"Normal Fields - LiveTable","doc":"The fields you want should be defined under the fields() function. This function needs to be passed to the live_table component in the template.\n  A basic guide to defining fields is as follows:\n\n  Define them as a keyword list, with the key being the name of the field (which will appear in the url and be used to reference the field) and a map of options which will contain more data about the field.\n  For eg,\n  ```elixir\n    def fields() do\n      [\n      id: %{label: \"ID\", sortable: true},\n      name: %{label: \"Name\", sortable: true, searchable: true},\n      email: %{label: \"Email\", sortable: true, searchable: true},\n      ]\n    end\n  ```\n  The map contains the label, and config for sort and search. The label will be the column header in the table and the exported CSV/PDF.\n\n\n  **Only fields with `sortable: true` will have a sortable link generated as the column header**.\n\n\n  **All fields with `searchable: true` will be searched from the search bar using the `ILIKE` operator**.","ref":"LiveTable.html#module-normal-fields"},{"type":"module","title":"Associated Fields - LiveTable","doc":"For associated fields, you can use the `assoc` key to specify the association, with a tuple containing the table name and the field.\n  For eg,\n  ```elixir\n    def fields() do\n      [\n      id: %{label: \"ID\", sortable: true},\n      supplier: %{\n        label: \"Supplier\",\n        sortable: true,\n        searchable: true,\n        assoc: {:supplier, :name}\n      },\n      supplier_description: %{\n        label: \"Supplier Email\",\n        assoc: {:suppliers, :contact_info},\n        searchable: false,\n        sortable: true\n      },\n      category_name: %{\n        label: \"Category Name\",\n        assoc: {:category, :name},\n        searchable: false,\n        sortable: false\n      },\n      image: %{\n        label: \"Image\",\n        sortable: false,\n        searchable: false,\n        assoc: {:image, :url}\n      },\n      ]\n    end\n  ```\n  Be it any type of association, you can join using the `assoc` key.","ref":"LiveTable.html#module-associated-fields"},{"type":"module","title":"Computed Fields - LiveTable","doc":"You can also define computed fields, which are fields that are not present in the database but are computed using a function.\n  This is useful in cases like calculating the total price of a product based on the quantity and price.\n  Such fields require a `computed:` key, which should get a dynamic query expression.\n\n  Since it is a dynamic query, you can use it to alias associated fields and use them inside the fragment.\n  For eg,\n  ```elixir\n    def fields() do\n      [\n        amount: %{\n          label: \"Amount\",\n          sortable: true,\n          searchable: false,\n          computed: dynamic([resource: r, suppliers: s, categories: c], fragment(\"? * ?\", r.price, r.stock_quantity))\n        }\n      ]\n    end\n  ```\n\n  If the field has not already been joined by a previous field, you can join it in the computed field itself.\n  For eg,\n  ```elixir\n    def fields() do\n      [\n        amount: %{\n          label: \"Amount\",\n          sortable: true,\n          searchable: false,\n          assoc: {:image, :url}\n          computed: dynamic([resource: r, images: i], fragment(\"? * ?\", r.price, r.stock_quantity)),\n        }\n      ]\n    end\n  ```","ref":"LiveTable.html#module-computed-fields"},{"type":"module","title":"Defining your filters - LiveTable","doc":"Your filters should be defined under the filters() function. This function needs to be passed to the live_table component in the template.\n  A basic guide to defining them is as follows:\n\n  Define them as a keyword list, with the key being the name of the filter (which will appear in the url and be used to reference the filter) and a map of options which will contain more info about the filter.\n\n  Each filter is defined by a struct of the corresponding filter type. The struct should be created using the new() function of the filter type.\n  The struct takes 3 arguments, the field the filter should act on, a key referencing the filter(to be used in the url), and a map of options which will contain more info about the filter.\n\n  As a general rule of thumb, the field should be the name of the field as an atom(in case of a normal field) or a tuple containing the table name and the field name(in case of an associated field).\n\n  A detailed guide for defining each type of filter has been provided in its corresponding module.","ref":"LiveTable.html#module-defining-your-filters"},{"type":"module","title":"License - LiveTable","doc":"MIT License. See LICENSE file for details.","ref":"LiveTable.html#module-license"},{"type":"module","title":"Contributing - LiveTable","doc":"1. Fork the repository\n  2. Create your feature branch (`git checkout -b feature/amazing-feature`)\n  3. Commit your changes (`git commit -m 'Add amazing feature'`)\n  4. Push to the branch (`git push origin feature/amazing-feature`)\n  5. Open a Pull Request","ref":"LiveTable.html#module-contributing"},{"type":"module","title":"LiveTable.Boolean","doc":"A module for handling boolean (checkbox) filters in LiveTable.\n  \n  This module provides functionality for creating and managing boolean filters implemented\n  as checkboxes in the LiveTable interface. It's designed to handle simple true/false\n  filtering scenarios with customizable options and conditions.","ref":"LiveTable.Boolean.html"},{"type":"module","title":"Options - LiveTable.Boolean","doc":"The boolean filter accepts the following options:\n- `:label` - The text label displayed next to the checkbox\n- `:condition` - The Ecto query condition to be applied when the checkbox is checked (a dynamic query)\n- `:class` - Optional CSS classes for the checkbox","ref":"LiveTable.Boolean.html#module-options"},{"type":"module","title":"Examples - LiveTable.Boolean","doc":"```elixir\n# Creating a basic boolean filter for active status\nBoolean.new(:active, \"active_filter\", %{\n  label: \"Show Active Only\",\n  condition: dynamic([p], p.active == true)\n})\n\n# Creating a boolean filter with a complex condition\nBoolean.new(:premium, \"premium_filter\", %{\n  label: \"Premium Users\",\n  condition: dynamic([p], p.subscription_level == \"premium\" and p.active == true)\n})\n```\nSince the condition is a dynamic query, you can give conditions using joined fields as well.\n```elixir\nBoolean.new(\n  :supplier_email,\n  \"supplier\",\n  %{\n    label: \"Email\",\n    condition: dynamic([p, s], s.contact_info == \"procurement@autopartsdirect.com\")\n  }\n)\n```\n> **Note**: Remember to use aliases in the same order you defined your fields.","ref":"LiveTable.Boolean.html#module-examples"},{"type":"module","title":"LiveTable.Range","doc":"A module for handling range-based filters in LiveTable.\n\nThis module provides functionality for creating and managing range filters that can handle\nnumeric values, dates, and datetimes. It supports creating range sliders with customizable\noptions and appearances.\n\nMakes use of nouislider under the hood for creating the range slider.\nSee the [noUiSlider documentation](https://refreshless.com/nouislider/) for more details\non customizing the slider behavior and appearance.\n\n> **Note**: Requires the TableHooks to be imported in your app.js","ref":"LiveTable.Range.html"},{"type":"module","title":"Options - LiveTable.Range","doc":"The module accepts the following options:\n- `:type` - The type of range filter (`:number`, `:date`, or `:datetime`)\n- `:label` - The label text for the range filter\n- `:unit` - The unit to display after the label (optional)\n- `:css_classes` - CSS classes for the main container\n- `:slider_classes` - CSS classes for the slider element\n- `:label_classes` - CSS classes for the label element\n\nFor default values, see: [LiveTable.Range source code](https://github.com/your-repo/admin-table/blob/main/lib/live_table/range.ex)","ref":"LiveTable.Range.html#module-options"},{"type":"module","title":"Types Support - LiveTable.Range","doc":"The module supports three types of range filters:\n- `:number` - For numeric ranges\n- `:date` - For date ranges\n- `:datetime` - For datetime ranges\n\n\n### :number\nFor numeric ranges with configurable min, max and step values:\n\n```elixir\nRange.new(:price, \"price_range\", %{\n  type: :number,\n  label: \"Price\",\n  default_min: 0,\n  default_max: 1000,\n  step: 10\n})\n# Renders a range filter with from 0 to 1000 with a step of 10.\n```\n\n### :date\nFor date ranges with customizable date boundaries:\n\n```elixir\nRange.new(:created_at, \"date_range\", %{\n  type: :date,\n  label: \"Creation Date\",\n  default_min: ~D[2024-01-01],\n  default_max: ~D[2024-12-31]\n})\n# Renders a date range filter with dates from 2024-01-01 to 2024-12-31.\n```\n\n### :datetime\nFor datetime ranges with configurable datetime boundaries:\n\n```elixir\nRange.new(:updated_at, \"datetime_range\", %{\n  type: :datetime,\n  label: \"Last Updated\",\n  default_min: ~N[2024-01-01 00:00:00],\n  default_max: ~N[2024-12-31 23:59:59],\n  step: 3600 # Step in seconds\n})\n# Renders a datetime range filter with dates from 2024-01-01 00:00:00 to 2024-12-31 23:59:59.\n# Remember to pass the datetime values in `NaiveDateTime` format.\n```","ref":"LiveTable.Range.html#module-types-support"},{"type":"module","title":"Examples - LiveTable.Range","doc":"```elixir\n# Creating a numeric range filter\nRange.new(:price, \"price_range\", %{\n  type: :number,\n  label: \"Price Range\",\n  unit: \"$\",\n  min: 0,\n  max: 1000,\n  step: 10\n})\n\n# Creating a date range filter\nRange.new(:created_at, \"date_range\", %{\n  type: :date,\n  label: \"Date Range\",\n  min: ~D[2024-01-01],\n  max: ~D[2024-12-31]\n})\n```\nIf you want to use the range filter with a joined schema, you can pass the field as a tuple, with the table name and the field-\n```elixir\nRange.new({:suppliers, :created_at}, \"created_at\", %{\n  type: :date,\n  label: \"Supplier Creation\",\n  min: ~D[2024-01-01],\n  max: ~D[2024-12-31],\n})\n```","ref":"LiveTable.Range.html#module-examples"},{"type":"module","title":"TODO: - LiveTable.Range","doc":"- [ ] Set slider value based on URL params\n- [ ] Format the slider appearance. Apply classes at [Preline UI](https://preline.co/docs/advanced-range-slider.html#range-with-tooltip)\n- [ ] Add support for customizing the range slider appearance(The slider classes should apply to the slider element)","ref":"LiveTable.Range.html#module-todo"},{"type":"module","title":"LiveTable.Select","doc":"A module for handling select-based filters in LiveTable.\n\n  This module provides functionality for creating and managing select filters that can handle\n  single or multiple selections. It supports both static options and dynamic option loading,\n  with customizable appearances and templates.","ref":"LiveTable.Select.html"},{"type":"module","title":"Options - LiveTable.Select","doc":"The module accepts the following options:\n  - `:label` - The label text for the select filter\n  - `:options` - Static list of options for the select\n  - `:options_source` - Function or module for dynamic option loading\n  - `:option_template` - Custom template for rendering options\n  - `:selected` - List of pre-selected values\n  - `:loading_text` - Text to display while loading options\n  - `:prompt` - Prompt text for the select\n  - `:placeholder` - Placeholder text for the select\n  - `:css_classes` - CSS classes for the main container\n  - `:label_classes` - CSS classes for the label element\n  - `:select_classes` - CSS classes for the select element\n\n  For default values, see: [LiveTable.Select source code](https://github.com/your-repo/admin-table/blob/main/lib/live_table/select.ex)","ref":"LiveTable.Select.html#module-options"},{"type":"module","title":"Working with Options - LiveTable.Select","doc":"There are two ways to configure and display options in the select filter:","ref":"LiveTable.Select.html#module-working-with-options"},{"type":"module","title":"1. Static Options - LiveTable.Select","doc":"The simplest approach using a predefined list of options:\n\n  ```elixir\n  Select.new(:status, \"status_select\", %{\n    label: \"Status\",\n    options: [\n      %{label: \"Active\", value: [1, \"Currently active\"]},\n      %{label: \"Pending\", value: [2, \"Awaiting processing\"]},\n      %{label: \"Archived\", value: [3, \"No longer active\"]}\n    ]\n  })\n  ```","ref":"LiveTable.Select.html#module-1-static-options"},{"type":"module","title":"2. Dynamic Options via `options_source` - LiveTable.Select","doc":"Load options dynamically using a function or module. Used for fetching new options based on typed input.\nUses `apply/3` under the hood to apply the function. Uses [`live-select-change`](git link) event to update the options.\n\n  ```elixir\n    # Point to your custom function\n    Select.new({:suppliers, :name}, \"supplier_name\", %{\n      label: \"Supplier\",\n      options_source: {Demo.Catalog, :search_suppliers, []} # Same as you'd use for `apply/3`\n    })\n\n    # in your context module\n    def search_suppliers(text) do\n      Supplier\n      |> where([c], ilike(c.name, ^\"%#{text}%\"))\n      |> select([c], {c.name, [c.id, c.contact_info]})\n      |> Repo.all()\n    end\n  ```\n\n  You could write your function to have other args passed to it as well. Just make sure the first arg is the text.\n  It must return a tuple, with the first element being the label and the second being the value(or a list of fields).","ref":"LiveTable.Select.html#module-2-dynamic-options-via-options_source"},{"type":"module","title":"Option Templates - LiveTable.Select","doc":"You can provide custom templates for rendering options in two ways:\n  1. Using the default template format for options with label and value pairs\n  2. Providing a custom template function through the `:option_template` option","ref":"LiveTable.Select.html#module-option-templates"},{"type":"module","title":"Default Template - LiveTable.Select","doc":"The default template expects options in the format:\n  ```elixir\n  %{label: label, value: [id, description]}\n  ```\n  The default template can be seen at [git link](https://)","ref":"LiveTable.Select.html#module-default-template"},{"type":"module","title":"Custom Template - LiveTable.Select","doc":"Custom templates can be provided as functions that take an option map and return rendered HTML:\n\n  ```elixir\n  def custom_template(option) do\n    assigns = %{option: option}\n    ~H\"\"\"\n     \n       <%= @option.label %>  inas\n       <%= @option.value |> Enum.at(0) %> \n     \n    \"\"\"\n  end\n\n  # in your filter definition\n  Select.new({:suppliers, :name}, \"supplier_name\", %{\n    label: \"Supplier\",\n    placeholder: \"Search for suppliers...\",\n    options_source: {Demo.Catalog, :search_suppliers, []}\n    option_template: &custom_template/1\n  })\n  ```\n\n  Each method can be combined with others - for example, you could use dynamic or static options with\n  custom templates.","ref":"LiveTable.Select.html#module-custom-template"},{"type":"module","title":"Examples - LiveTable.Select","doc":"If the field you want to use is part of the base schema(given to `LiveResource`), you can simply pass the field name as an atom.\n  ```elixir\n  # Creating a basic select filter\n  Select.new(:category, \"category_select\", %{\n    label: \"Category\",\n    options: [\n      %{label: \"Electronics\", value: [1, \"Electronics\"]},\n      %{label: \"Books\", value: [2, \"Books\"]}\n    ]\n  })\n  ```\n\n  If its part of a joined schema, you can pass it as a tuple, with the table name and field name as shown-\n  ```elixir\n  # Creating a select filter with options loaded from database\n  Select.new({:suppliers, :name}, \"supplier_name\", %{\n      label: \"Supplier\",\n      options_source: {Demo.Catalog, :search_suppliers, []}\n    })\n  ```\n\n  ```elixir\n  # Advanced example with all options\n  Select.new({:category, :name}, \"category_name\", %{\n    label: \"Category\",\n    placeholder: \"Search for categories...\",\n    options_source: {Demo.Catalog, :search_categories, [optional args]}\n    option_template: &custom_template/1,\n  })\n  ```\n\n  Currently, nested relations are not supported.","ref":"LiveTable.Select.html#module-examples"},{"type":"module","title":"TODO: - LiveTable.Select","doc":"- [ ] Interface the select classes with the live-select component.\n  - [ ] Update state from URL params.\n  - [ ] Add support for multiple option selection.\n  - [ ] Move away from live_select","ref":"LiveTable.Select.html#module-todo"},{"type":"extras","title":"Live Table","doc":"# Live Table\n\n  LiveTable is a powerful Phoenix LiveView component library that provides dynamic, interactive tables with built-in support for sorting, filtering, pagination, and data export capabilities.\n  Makes use of [`Oban`](https://hex.pm/packages/oban), [`NimbleCSV`](https://hex.pm/packages/nimble_csv) and [`Typst`](https://typst.app/universe) to handle exports.\n\n  **You can find a table with 1 Million rows [here](https://live-table.fly.dev)**","ref":"readme.html"},{"type":"extras","title":"Features - Live Table","doc":"- **Advanced Filtering System**\n    - Text search across multiple fields\n    - Range filters for numbers, dates, and datetimes\n    - Boolean filters with custom conditions\n    - Select filters with static and dynamic options\n    - Multi-column filtering support\n\n  - **Smart Sorting**\n    - Multi-column sorting\n    - Sortable associated fields\n    - Customizable sort directions\n    - Shift-click support for multi-column sorting\n\n  - **Flexible Pagination**\n    - Configurable page sizes\n    - Dynamic page navigation\n    - Efficient database querying\n\n  - **Export Capabilities**\n    - CSV export with background processing\n    - PDF export using Typst\n    - Custom file naming and formatting\n    - Progress tracking for large exports\n\n  - **Real-time Updates**\n    - LiveView integration\n    - Instant filter feedback\n    - Background job status updates","ref":"readme.html#features"},{"type":"extras","title":"Installation - Live Table","doc":"Add `live_table` to your list of dependencies in `mix.exs`:\n\n  ```elixir\n  def deps do\n    [\n      {:live_table, \"~> 0.2.0\"}\n    ]\n  ```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Live Table","doc":"Configure LiveTable in your `config/config.exs`:\n\n  ```elixir\n  config :live_table,\n    repo: YourApp.Repo,\n    pubsub: YourApp.PubSub,\n    components: YourApp.Components  # Optional, defaults to LiveTable.Components\n  ```","ref":"readme.html#configuration"},{"type":"extras","title":"JavaScript Setup - Live Table","doc":"Add the following to your `assets/js/app.js`:\n\n  ```js\n  import { TableHooks } from \"../../deps/live_table/priv/static/live-table.js\"\n  let liveSocket = new LiveSocket(\"/live\", Socket, {\n    params: {_csrf_token: csrfToken},\n    hooks: TableHooks\n  })\n  ```","ref":"readme.html#javascript-setup"},{"type":"extras","title":"CSS Setup - Live Table","doc":"Add the following to your `assets/tailwind.config.js`:\n\n```javascript\ncontent: [\n  // Other paths\n  \"../deps/live_table/priv/static/*.js\",\n  \"../deps/live_table/**/*.*ex\"\n]\n```\nAnd add the following to your `assets/css/app.css`:\n```css\n@import \"../../deps/live_table/priv/static/live-table.css\";\n```","ref":"readme.html#css-setup"},{"type":"extras","title":"Oban - Live Table","doc":"Configure your Oban instance and queues in your `config/config.exs`:\n\n```elixir\n# config/config.exs\nconfig :live_table, Oban,\n  repo: YourApp.Repo,\n  engine: Oban.Engines.Basic,\n  notifier: Oban.Notifiers.Postgres,\n  plugins: [Oban.Plugins.Pruner],\n  queues: [exports: 10]\n  # the queue named `exports` will be used for export jobs\n```\n\n#### Oban Web: Optional\nYou can configure oban web in your router to monitor the background jobs.\n\n  ```elixir\n  # lib/your_app_web/router.ex\n  import Oban.Web.Router\n\n  scope \"/\", YouAppWeb do\n    # your other routes\n    oban_dashboard(\"/oban\")\n  end\n  ```\n\n> **Note**: Remember to add exports to your list of allowed `static_paths` in `lib/app_web.ex`\n\n```elixir\ndef static_paths, do: ~w(assets fonts images favicon.ico exports robots.txt)\n```","ref":"readme.html#oban"},{"type":"extras","title":"Basic Usage - Live Table","doc":"In your LiveView add the line `use LiveTable.LiveResource`:\n\n  Define your fields and filters as required.\n  ```elixir\n  #/app_web/live/user_live/index.ex\n  defmodule MyAppWeb.UserLive.Index do\n    use MyAppWeb, :live_view\n    use LiveTable.LiveResource, resource: \"users\", schema: User # Add this line\n\n    # Define fields\n    def fields do\n      [\n        id: %{label: \"ID\", sortable: true},\n        name: %{label: \"Name\", sortable: true, searchable: true},\n        email: %{label: \"Email\", sortable: true, searchable: true},\n\n        # Include fields from associations\n        supplier: %{\n          label: \"Supplier\",\n          sortable: true,\n          searchable: true,\n          assoc: {:supplier, :name}\n        }\n      ]\n    end\n\n    # Define filters\n    def filters do\n      [\n        # Boolean filter\n        active: Boolean.new(:active, \"active\", %{\n          label: \"Active Users\",\n          condition: dynamic([q], q.active == true)\n        }),\n\n        # Range filter\n        age: Range.new(:age, \"age\", %{\n          type: :number,\n          label: \"Age Range\",\n          min: 0,\n          max: 100\n        }),\n\n        # Select filter with dynamic options\n        supplier: Select.new({:suppliers, :name}, \"supplier\", %{\n          label: \"Supplier\",\n          options_source: {YourApp.Suppliers, :search_suppliers, []}\n        })\n      ]\n    end\n  ```\n\n  ```elixir\n    #/app_web/live/user_live/index.html.heex\n    # in your view:\n    <.live_table\n      fields={fields()}\n      filters={filters()}\n      options={@options}\n      streams={@streams}\n    />\n  ```\n\n  > **Note**: Using `shift` + click on a column header will sort by multiple columns.","ref":"readme.html#basic-usage"},{"type":"extras","title":"Filter Types - Live Table","doc":"","ref":"readme.html#filter-types"},{"type":"extras","title":"Boolean Filter - Live Table","doc":"```elixir\n  Boolean.new(:active, \"active_filter\", %{\n    label: \"Show Active Only\",\n    condition: dynamic([p], p.active == true)\n  })\n  ```","ref":"readme.html#boolean-filter"},{"type":"extras","title":"Range Filter - Live Table","doc":"```elixir\n  Range.new(:price, \"price_range\", %{\n    type: :number,\n    label: \"Price Range\",\n    min: 0,\n    max: 1000,\n    step: 10\n  })\n  ```","ref":"readme.html#range-filter"},{"type":"extras","title":"Select Filter - Live Table","doc":"```elixir\n  Select.new(:category, \"category_select\", %{\n    label: \"Category\",\n    options: [\n      %{label: \"Electronics\", value: [1, \"Electronics\"]},\n      %{label: \"Books\", value: [2, \"Books\"]}\n    ]\n  })\n  ```","ref":"readme.html#select-filter"},{"type":"extras","title":"Defining your fields - Live Table","doc":"","ref":"readme.html#defining-your-fields"},{"type":"extras","title":"Normal Fields - Live Table","doc":"The fields you want should be defined under the fields() function. This function needs to be passed to the live_table component in the template.\n  A basic guide to defining fields is as follows:\n\n  Define them as a keyword list, with the key being the name of the field (which will appear in the url and be used to reference the field) and a map of options which will contain more data about the field.\n  For eg,\n  ```elixir\n    def fields() do\n      [\n      id: %{label: \"ID\", sortable: true},\n      name: %{label: \"Name\", sortable: true, searchable: true},\n      email: %{label: \"Email\", sortable: true, searchable: true},\n      ]\n    end\n  ```\n  The map contains the label, and config for sort and search. The label will be the column header in the table and the exported CSV/PDF.\n\n\n  **Only fields with `sortable: true` will have a sortable link generated as the column header**.\n\n\n  **All fields with `searchable: true` will be searched from the search bar using the `ILIKE` operator**.","ref":"readme.html#normal-fields"},{"type":"extras","title":"Associated Fields - Live Table","doc":"For associated fields, you can use the `assoc` key to specify the association, with a tuple containing the table name and the field.\n  For eg,\n  ```elixir\n    def fields() do\n      [\n      id: %{label: \"ID\", sortable: true},\n      supplier: %{\n        label: \"Supplier\",\n        sortable: true,\n        searchable: true,\n        assoc: {:supplier, :name}\n      },\n      supplier_description: %{\n        label: \"Supplier Email\",\n        assoc: {:suppliers, :contact_info},\n        searchable: false,\n        sortable: true\n      },\n      category_name: %{\n        label: \"Category Name\",\n        assoc: {:category, :name},\n        searchable: false,\n        sortable: false\n      },\n      image: %{\n        label: \"Image\",\n        sortable: false,\n        searchable: false,\n        assoc: {:image, :url}\n      },\n      ]\n    end\n  ```\n  Be it any type of association, you can join using the `assoc` key.","ref":"readme.html#associated-fields"},{"type":"extras","title":"Computed Fields - Live Table","doc":"You can also define computed fields, which are fields that are not present in the database but are computed using a function.\n  This is useful in cases like calculating the total price of a product based on the quantity and price.\n  Such fields require a `computed:` key, which should get a dynamic query expression.\n\n  Since it is a dynamic query, you can use it to alias associated fields and use them inside the fragment.\n  For eg,\n  ```elixir\n    def fields() do\n      [\n        amount: %{\n          label: \"Amount\",\n          sortable: true,\n          searchable: false,\n          computed: dynamic([resource: r, suppliers: s, categories: c], fragment(\"? * ?\", r.price, r.stock_quantity))\n        }\n      ]\n    end\n  ```\n\n  If the field has not already been joined by a previous field, you can join it in the computed field itself.\n  For eg,\n  ```elixir\n    def fields() do\n      [\n        amount: %{\n          label: \"Amount\",\n          sortable: true,\n          searchable: false,\n          assoc: {:image, :url}\n          computed: dynamic([resource: r, images: i], fragment(\"? * ?\", r.price, r.stock_quantity)),\n        }\n      ]\n    end\n  ```","ref":"readme.html#computed-fields"},{"type":"extras","title":"Defining your filters - Live Table","doc":"Your filters should be defined under the filters() function. This function needs to be passed to the live_table component in the template.\n  A basic guide to defining them is as follows:\n\n  Define them as a keyword list, with the key being the name of the filter (which will appear in the url and be used to reference the filter) and a map of options which will contain more info about the filter.\n\n  Each filter is defined by a struct of the corresponding filter type. The struct should be created using the new() function of the filter type.\n  The struct takes 3 arguments, the field the filter should act on, a key referencing the filter(to be used in the url), and a map of options which will contain more info about the filter.\n\n  As a general rule of thumb, the field should be the name of the field as an atom(in case of a normal field) or a tuple containing the table name and the field name(in case of an associated field).\n\n  A detailed guide for defining each type of filter has been provided in its corresponding module.","ref":"readme.html#defining-your-filters"},{"type":"extras","title":"License - Live Table","doc":"MIT License. See LICENSE file for details.","ref":"readme.html#license"},{"type":"extras","title":"Contributing - Live Table","doc":"1. Fork the repository\n  2. Create your feature branch (`git checkout -b feature/amazing-feature`)\n  3. Commit your changes (`git commit -m 'Add amazing feature'`)\n  4. Push to the branch (`git push origin feature/amazing-feature`)\n  5. Open a Pull Request","ref":"readme.html#contributing"},{"type":"extras","title":"Exports","doc":"# Exports","ref":"exports.html"},{"type":"extras","title":"Export Support - Exports","doc":"LiveTable supports both CSV and PDF exports with background processing. \nIt uses Oban to handle bakground jobs, so that export file can be prepared without hanging the LiveView.\n\n- CSV exports are handled by [`LiveTable.CsvGenerator`](https://github.com/gurujada/live_table/blob/master/lib/live_table/csv_generator.ex).\n  Makes use of [`NimbleCSV`](https://hex.pm/packages/nimble_csv) under the hood.\n- PDF exports use [`Typst`](https://typst.app/universe) for formatting and generation. Handled by [`LiveTable.PdfGenerator`](https://github.com/gurujada/live_table/blob/master/lib/live_table/pdf_generator.ex)\n\nThe headers are the same as that rendered by the table. By default, all records are exported without pagination.","ref":"exports.html#export-support"},{"type":"extras","title":"Configuration - Exports","doc":"","ref":"exports.html#configuration"},{"type":"extras","title":"Oban - Exports","doc":"Configure your Oban instance and queues in your `config.exs`:\n\n```elixir\n# config/config.exs\nconfig :live_table, Oban,\n  repo: YourApp.Repo,\n  engine: Oban.Engines.Basic,\n  notifier: Oban.Notifiers.Postgres,\n  plugins: [Oban.Plugins.Pruner],\n  queues: [exports: 10]\n  # the queue named `exports` will be used for export jobs\n```\n\n#### Oban Web: Optional\nYou can configure oban web in your router to monitor the background jobs.\n  \n  ```elixir\n  # lib/your_app_web/router.ex\n  import Oban.Web.Router\n \n  scope \"/\", YouAppWeb do\n    # your other routes\n    oban_dashboard(\"/oban\")\n  end\n  ```\n\n> **Note**: Remember to add exports to your list of allowed static paths in `lib/app_web.ex`\n\n```elixir\ndef static_paths, do: ~w(assets fonts images favicon.ico exports robots.txt)\n```","ref":"exports.html#oban"},{"type":"extras","title":"CSV Exports - Exports","doc":"LiveTable uses [`NimbleCSV`](https://hex.pm/packages/nimble_csv) in conjunction with Oban for handling CSV exports.\nRecords are streamed inside of a [`Repo.transaction/2`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:transaction/2) function using [`Repo.stream/2`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:stream/2),\nso that no more than a 1000 records are loaded into memory at a time.\nThis makes it extremely efficient and blazing fast for exporting large datasets, all the while remaining scalable.","ref":"exports.html#csv-exports"},{"type":"extras","title":"PDF Exports - Exports","doc":"LiveTable uses [`Typst`](https://typst.app/universe) in conjunction with Oban for handling PDF exports.\nTypst is a Rust based typesetting engine that generates PDFs from .tp files\nThis makes it extremely fast and well suited to handle large datasets.\n\nRecords are streamed inside of a [`Repo.transaction/2`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:transaction/2) function using [`Repo.stream/2`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:stream/2),\nso that no more than a 500 records are loaded into memory at a time.\n\n> **Note**: LiveTable uses `System.cmd/2` to compile the .tp file into a PDF. Ensure that you have `typst` installed on your system.","ref":"exports.html#pdf-exports"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}